summaryrefslogtreecommitdiffstats
path: root/kopete/libkopete/kautoconfig.cpp
diff options
context:
space:
mode:
Diffstat (limited to 'kopete/libkopete/kautoconfig.cpp')
-rw-r--r--kopete/libkopete/kautoconfig.cpp4
1 files changed, 2 insertions, 2 deletions
diff --git a/kopete/libkopete/kautoconfig.cpp b/kopete/libkopete/kautoconfig.cpp
index c6c0b2c0..14c5efaf 100644
--- a/kopete/libkopete/kautoconfig.cpp
+++ b/kopete/libkopete/kautoconfig.cpp
@@ -64,7 +64,7 @@ public:
// Widgets to parse
TQPtrList<TQWidget> widgets;
// Name of the group that KConfig should be set to for each widget.
TQMap<TQWidget*, TQString> groups;
// Child widgets of widgets to ignore
@@ -101,7 +101,7 @@ public:
}
};
-KAutoConfig::KAutoConfig(KConfig *kconfig, TQObject *parent,
+KAutoConfig::KAutoConfig(TDEConfig *kconfig, TQObject *parent,
const char *name) : TQObject(parent, name), config(kconfig) {
d = new KAutoConfigPrivate();
}
@@ -64,7 +64,7 @@ public:
// Widgets to parse
TQPtrList<TQWidget> widgets;
- // Name of the group that KConfig should be set to for each widget.
+ // Name of the group that TDEConfig should be set to for each widget.
TQMap<TQWidget*, TQString> groups;
// Child widgets of widgets to ignore